@@ -6,7 +6,8 @@
 # URL: <https://github.com/Yzstr/CRTK>
 # For license information, see LICENSE
 
-from utilities import opcode_occurrence
+from crtk.utilities import opcode_occurrence
+
 
 class Contract(object):
     def __init__(self):
@@ -49,8 +50,6 @@ class Contract(object):
     def is_real_contract(self):
         return self.real_contract
 
-    def get_opcode_occurrence(self, collapse = 0):
+    def get_opcode_occurrence(self, collapse=0):
         opcode_list = [item[2] for item in self.opcode]
         return opcode_occurrence(opcode_list, collapse)
-
-        
