@@ -6,8 +6,8 @@
 # URL: <https://github.com/Yzstr/CRTK>
 # For license information, see LICENSE
 
-from contract import Contract
-from utilities import *
+from crtk.contract import Contract
+from crtk.utilities import get_function_signatures_list, check_ERC_standard, get_opcode_list
 
 
 class RuntimeContract(Contract):
@@ -29,7 +29,7 @@ class RuntimeContract(Contract):
         self.function_signatures = get_function_signatures_list(self.opcode)
 
         if len(self.function_signatures) > 0:
-            self.real_contract = True 
+            self.real_contract = True
         else:
             self.real_contract = False
 
@@ -40,6 +40,3 @@ class RuntimeContract(Contract):
         if check_ERC_standard(self.function_signatures, standard='ERC777'):
             self.ERC777 = True
 
-
-
-
